aise
====

.. image:: https://img.shields.io/pypi/v/aise.svg
    :target: https://pypi.python.org/pypi/aise
    :alt: Latest PyPI version

.. image:: https://github.com/johnjrhunglin/aise/blob/main/README.md.png
   :target: https://github.com/johnjrhunglin/aise/blob/main/README.md
   :alt: Latest Travis CI build status

Functions used to analyze data in science education

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`aise` was written by `John J. H. Lin <john.jrhunglin@gmail.com>`_.
